@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::CellsObjectOperateTaskParameter;
 
 require 5.6.0;
@@ -36,11 +35,11 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::OperateObject;
 use AsposeCellsCloud::Object::OperateParameter;
-use AsposeCellsCloud::Object::TaskParameter;
+use AsposeCellsCloud::Object::TaskParameter; 
+
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -56,12 +55,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -102,7 +101,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -110,7 +109,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -122,49 +121,49 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'CellsObjectOperateTaskParameter',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'operate_parameter' => {
-    	datatype => 'OperateParameter',
-    	base_name => 'OperateParameter',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'destination_workbook' => {
-    	datatype => 'FileSource',
-    	base_name => 'DestinationWorkbook',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'operate_object' => {
-    	datatype => 'OperateObject',
-    	base_name => 'OperateObject',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'operate_object' => {
+     	datatype => 'OperateObject',
+     	base_name => 'OperateObject',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'operate_parameter' => {
+     	datatype => 'OperateParameter',
+     	base_name => 'OperateParameter',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'destination_workbook' => {
+     	datatype => 'FileSource',
+     	base_name => 'DestinationWorkbook',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
+    'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
-    'destination_workbook' => 'FileSource',
-    'operate_object' => 'OperateObject'
+    'destination_workbook' => 'FileSource' 
 } );
 
 __PACKAGE__->attribute_map( {
+    'operate_object' => 'OperateObject',
     'operate_parameter' => 'OperateParameter',
-    'destination_workbook' => 'DestinationWorkbook',
-    'operate_object' => 'OperateObject'
+    'destination_workbook' => 'DestinationWorkbook' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
