@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::ChartFrame;
 
 require 5.6.0;
@@ -36,12 +35,11 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-
 use AsposeCellsCloud::Object::Area;
 use AsposeCellsCloud::Object::Font;
 use AsposeCellsCloud::Object::Line;
-use AsposeCellsCloud::Object::Link;
-use AsposeCellsCloud::Object::LinkElement;
+use AsposeCellsCloud::Object::LinkElement; 
+
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -57,12 +55,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -103,7 +101,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -111,7 +109,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -123,148 +121,139 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'ChartFrame',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'link' => {
-    	datatype => 'Link',
-    	base_name => 'link',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'is_inner_mode' => {
-    	datatype => 'boolean',
-    	base_name => 'IsInnerMode',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'shape_properties' => {
-    	datatype => 'ARRAY[LinkElement]',
-    	base_name => 'ShapeProperties',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'auto_scale_font' => {
-    	datatype => 'boolean',
-    	base_name => 'AutoScaleFont',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'area' => {
-    	datatype => 'Area',
-    	base_name => 'Area',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'height' => {
-    	datatype => 'int',
-    	base_name => 'Height',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'width' => {
-    	datatype => 'int',
-    	base_name => 'Width',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'background_mode' => {
-    	datatype => 'string',
-    	base_name => 'BackgroundMode',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'is_automatic_size' => {
-    	datatype => 'boolean',
-    	base_name => 'IsAutomaticSize',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'y' => {
-    	datatype => 'int',
-    	base_name => 'Y',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'x' => {
-    	datatype => 'int',
-    	base_name => 'X',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'shadow' => {
-    	datatype => 'boolean',
-    	base_name => 'Shadow',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'font' => {
-    	datatype => 'Font',
-    	base_name => 'Font',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'border' => {
-    	datatype => 'Line',
-    	base_name => 'Border',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'area' => {
+     	datatype => 'Area',
+     	base_name => 'Area',
+     	description => 'Gets the area. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'auto_scale_font' => {
+     	datatype => 'boolean',
+     	base_name => 'AutoScaleFont',
+     	description => 'True if the text in the object changes font size when the object size changes. The default value is True. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'background_mode' => {
+     	datatype => 'string',
+     	base_name => 'BackgroundMode',
+     	description => 'Gets and sets the display mode of the background ',
+     	format => '',
+     	read_only => '',
+     		},
+     'border' => {
+     	datatype => 'Line',
+     	base_name => 'Border',
+     	description => 'Gets the border. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'font' => {
+     	datatype => 'Font',
+     	base_name => 'Font',
+     	description => 'Gets a  object of the specified ChartFrame object. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'is_automatic_size' => {
+     	datatype => 'boolean',
+     	base_name => 'IsAutomaticSize',
+     	description => 'Indicates whether the chart frame is automatic sized. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'is_inner_mode' => {
+     	datatype => 'boolean',
+     	base_name => 'IsInnerMode',
+     	description => 'Indicates whether the size of the plot area size includes the tick marks, and the axis labels.            False specifies that the size shall determine the size of the plot area, the tick marks, and the axis labels. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'shadow' => {
+     	datatype => 'boolean',
+     	base_name => 'Shadow',
+     	description => 'True if the frame has a shadow. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'shape_properties' => {
+     	datatype => 'ARRAY[LinkElement]',
+     	base_name => 'ShapeProperties',
+     	description => 'Gets the  object. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'width' => {
+     	datatype => 'int',
+     	base_name => 'Width',
+     	description => 'Gets or sets the width of frame in units of 1/4000 of the chart area. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'height' => {
+     	datatype => 'int',
+     	base_name => 'Height',
+     	description => 'Gets or sets the height of frame in units of 1/4000 of the chart area. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'x' => {
+     	datatype => 'int',
+     	base_name => 'X',
+     	description => 'Gets or sets the x coordinate of the upper left corner in units of 1/4000 of the chart area. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'y' => {
+     	datatype => 'int',
+     	base_name => 'Y',
+     	description => 'Gets or sets the y coordinate of the upper left corner in units of 1/4000 of the chart area. ',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'link' => 'Link',
-    'is_inner_mode' => 'boolean',
-    'shape_properties' => 'ARRAY[LinkElement]',
-    'auto_scale_font' => 'boolean',
     'area' => 'Area',
-    'height' => 'int',
-    'width' => 'int',
+    'auto_scale_font' => 'boolean',
     'background_mode' => 'string',
-    'is_automatic_size' => 'boolean',
-    'y' => 'int',
-    'x' => 'int',
-    'shadow' => 'boolean',
+    'border' => 'Line',
     'font' => 'Font',
-    'border' => 'Line'
+    'is_automatic_size' => 'boolean',
+    'is_inner_mode' => 'boolean',
+    'shadow' => 'boolean',
+    'shape_properties' => 'ARRAY[LinkElement]',
+    'width' => 'int',
+    'height' => 'int',
+    'x' => 'int',
+    'y' => 'int' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'link' => 'link',
-    'is_inner_mode' => 'IsInnerMode',
-    'shape_properties' => 'ShapeProperties',
-    'auto_scale_font' => 'AutoScaleFont',
     'area' => 'Area',
-    'height' => 'Height',
-    'width' => 'Width',
+    'auto_scale_font' => 'AutoScaleFont',
     'background_mode' => 'BackgroundMode',
-    'is_automatic_size' => 'IsAutomaticSize',
-    'y' => 'Y',
-    'x' => 'X',
-    'shadow' => 'Shadow',
+    'border' => 'Border',
     'font' => 'Font',
-    'border' => 'Border'
+    'is_automatic_size' => 'IsAutomaticSize',
+    'is_inner_mode' => 'IsInnerMode',
+    'shadow' => 'Shadow',
+    'shape_properties' => 'ShapeProperties',
+    'width' => 'Width',
+    'height' => 'Height',
+    'x' => 'X',
+    'y' => 'Y' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
