@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::ColorFilter;
 
 require 5.6.0;
@@ -36,8 +35,8 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::CellsColor; 
 
-use AsposeCellsCloud::Object::CellsColor;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -53,12 +52,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -99,7 +98,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -107,7 +106,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -119,67 +118,67 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'ColorFilter',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'color' => {
-    	datatype => 'CellsColor',
-    	base_name => 'Color',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'pattern' => {
-    	datatype => 'string',
-    	base_name => 'Pattern',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'background_color' => {
-    	datatype => 'CellsColor',
-    	base_name => 'BackgroundColor',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'foreground_color_color' => {
-    	datatype => 'CellsColor',
-    	base_name => 'ForegroundColorColor',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'filter_by_fill_color' => {
-    	datatype => 'string',
-    	base_name => 'FilterByFillColor',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'filter_by_fill_color' => {
+     	datatype => 'boolean',
+     	base_name => 'FilterByFillColor',
+     	description => 'Flag indicating whether filter by the cell`s fill color. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'pattern' => {
+     	datatype => 'string',
+     	base_name => 'Pattern',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'color' => {
+     	datatype => 'CellsColor',
+     	base_name => 'Color',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'foreground_color_color' => {
+     	datatype => 'CellsColor',
+     	base_name => 'ForegroundColorColor',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'background_color' => {
+     	datatype => 'CellsColor',
+     	base_name => 'BackgroundColor',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'color' => 'CellsColor',
+    'filter_by_fill_color' => 'boolean',
     'pattern' => 'string',
-    'background_color' => 'CellsColor',
+    'color' => 'CellsColor',
     'foreground_color_color' => 'CellsColor',
-    'filter_by_fill_color' => 'string'
+    'background_color' => 'CellsColor' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'color' => 'Color',
+    'filter_by_fill_color' => 'FilterByFillColor',
     'pattern' => 'Pattern',
-    'background_color' => 'BackgroundColor',
+    'color' => 'Color',
     'foreground_color_color' => 'ForegroundColorColor',
-    'filter_by_fill_color' => 'FilterByFillColor'
+    'background_color' => 'BackgroundColor' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
