@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::ConvertTaskParameter;
 
 require 5.6.0;
@@ -36,10 +35,10 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::SaveOptions;
-use AsposeCellsCloud::Object::TaskParameter;
+use AsposeCellsCloud::Object::TaskParameter; 
+
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -55,12 +54,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -101,7 +100,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -109,7 +108,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -121,49 +120,58 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'ConvertTaskParameter',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'workbook' => {
-    	datatype => 'FileSource',
-    	base_name => 'Workbook',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'save_options' => {
-    	datatype => 'SaveOptions',
-    	base_name => 'SaveOptions',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'destination_file' => {
-    	datatype => 'string',
-    	base_name => 'DestinationFile',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'workbook' => {
+     	datatype => 'FileSource',
+     	base_name => 'Workbook',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'destination_file' => {
+     	datatype => 'string',
+     	base_name => 'DestinationFile',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'Region',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'save_options' => {
+     	datatype => 'SaveOptions',
+     	base_name => 'SaveOptions',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
     'workbook' => 'FileSource',
-    'save_options' => 'SaveOptions',
-    'destination_file' => 'string'
+    'destination_file' => 'string',
+    'region' => 'string',
+    'save_options' => 'SaveOptions' 
 } );
 
 __PACKAGE__->attribute_map( {
     'workbook' => 'Workbook',
-    'save_options' => 'SaveOptions',
-    'destination_file' => 'DestinationFile'
+    'destination_file' => 'DestinationFile',
+    'region' => 'Region',
+    'save_options' => 'SaveOptions' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
