@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::GradientFill;
 
 require 5.6.0;
@@ -36,8 +35,8 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::GradientFillStop; 
 
-use AsposeCellsCloud::Object::GradientFillStop;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -53,12 +52,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -99,7 +98,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -107,7 +106,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -119,58 +118,58 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'GradientFill',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'fill_type' => {
-    	datatype => 'string',
-    	base_name => 'FillType',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'angle' => {
-    	datatype => 'double',
-    	base_name => 'Angle',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'gradient_stops' => {
-    	datatype => 'ARRAY[GradientFillStop]',
-    	base_name => 'GradientStops',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'direction_type' => {
-    	datatype => 'string',
-    	base_name => 'DirectionType',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'fill_type' => {
+     	datatype => 'string',
+     	base_name => 'FillType',
+     	description => 'Gets the gradient fill type. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'direction_type' => {
+     	datatype => 'string',
+     	base_name => 'DirectionType',
+     	description => 'Gets the gradient direction type. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'angle' => {
+     	datatype => 'double',
+     	base_name => 'Angle',
+     	description => 'The angle of linear fill. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'gradient_stops' => {
+     	datatype => 'ARRAY[GradientFillStop]',
+     	base_name => 'GradientStops',
+     	description => 'Represents the gradient stop collection. ',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
     'fill_type' => 'string',
+    'direction_type' => 'string',
     'angle' => 'double',
-    'gradient_stops' => 'ARRAY[GradientFillStop]',
-    'direction_type' => 'string'
+    'gradient_stops' => 'ARRAY[GradientFillStop]' 
 } );
 
 __PACKAGE__->attribute_map( {
     'fill_type' => 'FillType',
+    'direction_type' => 'DirectionType',
     'angle' => 'Angle',
-    'gradient_stops' => 'GradientStops',
-    'direction_type' => 'DirectionType'
+    'gradient_stops' => 'GradientStops' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
