@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::ListColumn;
 
 require 5.6.0;
@@ -36,8 +35,8 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::Range; 
 
-use AsposeCellsCloud::Object::Range;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -53,12 +52,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -99,7 +98,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -107,7 +106,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -119,58 +118,67 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'ListColumn',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'totals_calculation' => {
-    	datatype => 'string',
-    	base_name => 'TotalsCalculation',
-    	description => 'Gets and sets the type of calculation in the Totals row of the list column.',
-    	format => '',
-    	read_only => '',
-    		},
-    'name' => {
-    	datatype => 'string',
-    	base_name => 'Name',
-    	description => 'Gets and sets the name of the column.',
-    	format => '',
-    	read_only => '',
-    		},
-    'formula' => {
-    	datatype => 'string',
-    	base_name => 'Formula',
-    	description => 'Gets and sets the formula of the list column.',
-    	format => '',
-    	read_only => '',
-    		},
-    'range' => {
-    	datatype => 'Range',
-    	base_name => 'Range',
-    	description => 'Gets and sets the formula of the list column.',
-    	format => '',
-    	read_only => '',
-    		},
+     'name' => {
+     	datatype => 'string',
+     	base_name => 'Name',
+     	description => 'Gets and sets the name of the column. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'range' => {
+     	datatype => 'Range',
+     	base_name => 'Range',
+     	description => 'Gets the range of this list column. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'totals_calculation' => {
+     	datatype => 'string',
+     	base_name => 'TotalsCalculation',
+     	description => 'Gets and sets the type of calculation in the Totals row of the list column. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'formula' => {
+     	datatype => 'string',
+     	base_name => 'Formula',
+     	description => 'Gets and sets the formula of the list column. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'totals_row_label' => {
+     	datatype => 'string',
+     	base_name => 'TotalsRowLabel',
+     	description => 'Gets and sets the display labels of total row. ',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'totals_calculation' => 'string',
     'name' => 'string',
+    'range' => 'Range',
+    'totals_calculation' => 'string',
     'formula' => 'string',
-    'range' => 'Range'
+    'totals_row_label' => 'string' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'totals_calculation' => 'TotalsCalculation',
     'name' => 'Name',
+    'range' => 'Range',
+    'totals_calculation' => 'TotalsCalculation',
     'formula' => 'Formula',
-    'range' => 'Range'
+    'totals_row_label' => 'TotalsRowLabel' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
