@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::SortKey;
 
 require 5.6.0;
@@ -36,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+ 
 
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
@@ -52,12 +52,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -98,7 +98,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -106,7 +106,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -118,76 +118,76 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'SortKey',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'custom_list' => {
-    	datatype => 'ARRAY[string]',
-    	base_name => 'CustomList',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'sort_order' => {
-    	datatype => 'string',
-    	base_name => 'SortOrder',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'key' => {
-    	datatype => 'int',
-    	base_name => 'Key',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'order' => {
-    	datatype => 'string',
-    	base_name => 'Order',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'type' => {
-    	datatype => 'string',
-    	base_name => 'Type',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'index' => {
-    	datatype => 'int',
-    	base_name => 'Index',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'key' => {
+     	datatype => 'int',
+     	base_name => 'Key',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'sort_order' => {
+     	datatype => 'string',
+     	base_name => 'SortOrder',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'custom_list' => {
+     	datatype => 'ARRAY[string]',
+     	base_name => 'CustomList',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'order' => {
+     	datatype => 'string',
+     	base_name => 'Order',
+     	description => 'Indicates the order of sorting.',
+     	format => '',
+     	read_only => '',
+     		},
+     'index' => {
+     	datatype => 'int',
+     	base_name => 'Index',
+     	description => 'Gets the sorted column index(absolute position, column A is 0, B is 1, ...).',
+     	format => '',
+     	read_only => '',
+     		},
+     'type' => {
+     	datatype => 'string',
+     	base_name => 'Type',
+     	description => 'Represents the type of sorting.',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'custom_list' => 'ARRAY[string]',
-    'sort_order' => 'string',
     'key' => 'int',
+    'sort_order' => 'string',
+    'custom_list' => 'ARRAY[string]',
     'order' => 'string',
-    'type' => 'string',
-    'index' => 'int'
+    'index' => 'int',
+    'type' => 'string' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'custom_list' => 'CustomList',
-    'sort_order' => 'SortOrder',
     'key' => 'Key',
+    'sort_order' => 'SortOrder',
+    'custom_list' => 'CustomList',
     'order' => 'Order',
-    'type' => 'Type',
-    'index' => 'Index'
+    'index' => 'Index',
+    'type' => 'Type' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
