@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::SpreadsheetML2003SaveOptions;
 
 require 5.6.0;
@@ -36,8 +35,8 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::SaveOptions; 
 
-use AsposeCellsCloud::Object::SaveOptions;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -53,12 +52,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -99,7 +98,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -107,7 +106,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -119,121 +118,121 @@ sub _deserialize {
 }
 
 
-
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options of saving .xml file.',
                                   class => 'SpreadsheetML2003SaveOptions',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'enable_http_compression' => {
-    	datatype => 'boolean',
-    	base_name => 'EnableHTTPCompression',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'save_format' => {
-    	datatype => 'string',
-    	base_name => 'SaveFormat',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'clear_data' => {
-    	datatype => 'boolean',
-    	base_name => 'ClearData',
-    	description => 'Make the workbook empty after saving the file.',
-    	format => '',
-    	read_only => '',
-    		},
-    'cached_file_folder' => {
-    	datatype => 'string',
-    	base_name => 'CachedFileFolder',
-    	description => 'The cached file folder is used to store some large data.',
-    	format => '',
-    	read_only => '',
-    		},
-    'validate_merged_areas' => {
-    	datatype => 'boolean',
-    	base_name => 'ValidateMergedAreas',
-    	description => 'Indicates whether validate merged areas before saving the file. The default value is false.             ',
-    	format => '',
-    	read_only => '',
-    		},
-    'refresh_chart_cache' => {
-    	datatype => 'boolean',
-    	base_name => 'RefreshChartCache',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'create_directory' => {
-    	datatype => 'boolean',
-    	base_name => 'CreateDirectory',
-    	description => 'If true and the directory does not exist, the directory will be automatically created before saving the file.             ',
-    	format => '',
-    	read_only => '',
-    		},
-    'sort_names' => {
-    	datatype => 'boolean',
-    	base_name => 'SortNames',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'export_column_index_of_cell' => {
-    	datatype => 'boolean',
-    	base_name => 'ExportColumnIndexOfCell',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'is_indented_formatting' => {
-    	datatype => 'boolean',
-    	base_name => 'IsIndentedFormatting',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'limit_as_xls' => {
-    	datatype => 'boolean',
-    	base_name => 'LimitAsXls',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'export_column_index_of_cell' => {
+     	datatype => 'boolean',
+     	base_name => 'ExportColumnIndexOfCell',
+     	description => 'The default value is false, it means that column index will be ignored if the cell is contiguous to the previous cell.',
+     	format => '',
+     	read_only => '',
+     		},
+     'is_indented_formatting' => {
+     	datatype => 'boolean',
+     	base_name => 'IsIndentedFormatting',
+     	description => 'Causes child elements to be indented.The default value is true.  If the value is false, it will reduce the size of the xml file',
+     	format => '',
+     	read_only => '',
+     		},
+     'limit_as_xls' => {
+     	datatype => 'boolean',
+     	base_name => 'LimitAsXls',
+     	description => 'Limit as xls, the max row index is 65535 and the max column index is 255.',
+     	format => '',
+     	read_only => '',
+     		},
+     'save_format' => {
+     	datatype => 'string',
+     	base_name => 'SaveFormat',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'cached_file_folder' => {
+     	datatype => 'string',
+     	base_name => 'CachedFileFolder',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'clear_data' => {
+     	datatype => 'boolean',
+     	base_name => 'ClearData',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'create_directory' => {
+     	datatype => 'boolean',
+     	base_name => 'CreateDirectory',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'enable_http_compression' => {
+     	datatype => 'boolean',
+     	base_name => 'EnableHTTPCompression',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'refresh_chart_cache' => {
+     	datatype => 'boolean',
+     	base_name => 'RefreshChartCache',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'sort_names' => {
+     	datatype => 'boolean',
+     	base_name => 'SortNames',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'validate_merged_areas' => {
+     	datatype => 'boolean',
+     	base_name => 'ValidateMergedAreas',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'enable_http_compression' => 'boolean',
-    'save_format' => 'string',
-    'clear_data' => 'boolean',
-    'cached_file_folder' => 'string',
-    'validate_merged_areas' => 'boolean',
-    'refresh_chart_cache' => 'boolean',
-    'create_directory' => 'boolean',
-    'sort_names' => 'boolean',
     'export_column_index_of_cell' => 'boolean',
     'is_indented_formatting' => 'boolean',
-    'limit_as_xls' => 'boolean'
+    'limit_as_xls' => 'boolean',
+    'save_format' => 'string',
+    'cached_file_folder' => 'string',
+    'clear_data' => 'boolean',
+    'create_directory' => 'boolean',
+    'enable_http_compression' => 'boolean',
+    'refresh_chart_cache' => 'boolean',
+    'sort_names' => 'boolean',
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'enable_http_compression' => 'EnableHTTPCompression',
-    'save_format' => 'SaveFormat',
-    'clear_data' => 'ClearData',
-    'cached_file_folder' => 'CachedFileFolder',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'refresh_chart_cache' => 'RefreshChartCache',
-    'create_directory' => 'CreateDirectory',
-    'sort_names' => 'SortNames',
     'export_column_index_of_cell' => 'ExportColumnIndexOfCell',
     'is_indented_formatting' => 'IsIndentedFormatting',
-    'limit_as_xls' => 'LimitAsXls'
+    'limit_as_xls' => 'LimitAsXls',
+    'save_format' => 'SaveFormat',
+    'cached_file_folder' => 'CachedFileFolder',
+    'clear_data' => 'ClearData',
+    'create_directory' => 'CreateDirectory',
+    'enable_http_compression' => 'EnableHTTPCompression',
+    'refresh_chart_cache' => 'RefreshChartCache',
+    'sort_names' => 'SortNames',
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
