@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::TextureFill;
 
 require 5.6.0;
@@ -36,10 +35,10 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-
 use AsposeCellsCloud::Object::LinkElement;
 use AsposeCellsCloud::Object::PicFormatOption;
-use AsposeCellsCloud::Object::TilePicOption;
+use AsposeCellsCloud::Object::TilePicOption; 
+
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -55,12 +54,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -101,7 +100,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -109,7 +108,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -121,76 +120,76 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'TextureFill',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'scale' => {
-    	datatype => 'double',
-    	base_name => 'Scale',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'image' => {
-    	datatype => 'LinkElement',
-    	base_name => 'Image',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'pic_format_option' => {
-    	datatype => 'PicFormatOption',
-    	base_name => 'PicFormatOption',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'tile_pic_option' => {
-    	datatype => 'TilePicOption',
-    	base_name => 'TilePicOption',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'transparency' => {
-    	datatype => 'double',
-    	base_name => 'Transparency',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'type' => {
-    	datatype => 'string',
-    	base_name => 'Type',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'type' => {
+     	datatype => 'string',
+     	base_name => 'Type',
+     	description => 'Gets and sets the texture type ',
+     	format => '',
+     	read_only => '',
+     		},
+     'transparency' => {
+     	datatype => 'double',
+     	base_name => 'Transparency',
+     	description => 'Returns or sets the degree of transparency of the area as a value from 0.0 (opaque) through 1.0 (clear). ',
+     	format => '',
+     	read_only => '',
+     		},
+     'scale' => {
+     	datatype => 'double',
+     	base_name => 'Scale',
+     	description => 'Gets and sets the picture format scale. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'tile_pic_option' => {
+     	datatype => 'TilePicOption',
+     	base_name => 'TilePicOption',
+     	description => 'Gets or sets tile picture option. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'pic_format_option' => {
+     	datatype => 'PicFormatOption',
+     	base_name => 'PicFormatOption',
+     	description => 'Gets or sets picture format option. ',
+     	format => '',
+     	read_only => '',
+     		},
+     'image' => {
+     	datatype => 'LinkElement',
+     	base_name => 'Image',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'scale' => 'double',
-    'image' => 'LinkElement',
-    'pic_format_option' => 'PicFormatOption',
-    'tile_pic_option' => 'TilePicOption',
+    'type' => 'string',
     'transparency' => 'double',
-    'type' => 'string'
+    'scale' => 'double',
+    'tile_pic_option' => 'TilePicOption',
+    'pic_format_option' => 'PicFormatOption',
+    'image' => 'LinkElement' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'scale' => 'Scale',
-    'image' => 'Image',
-    'pic_format_option' => 'PicFormatOption',
-    'tile_pic_option' => 'TilePicOption',
+    'type' => 'Type',
     'transparency' => 'Transparency',
-    'type' => 'Type'
+    'scale' => 'Scale',
+    'tile_pic_option' => 'TilePicOption',
+    'pic_format_option' => 'PicFormatOption',
+    'image' => 'Image' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
