@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetCellStyleRequest.name : Document name.  ,
+# GetWorksheetCellStyleRequest.name : The file name.  ,
 # GetWorksheetCellStyleRequest.sheetName : The worksheet name.  ,
 # GetWorksheetCellStyleRequest.cellName : Cell`s name.  ,
-# GetWorksheetCellStyleRequest.folder : Document`s folder.  ,
-# GetWorksheetCellStyleRequest.storageName : Storage name.   
+# GetWorksheetCellStyleRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetCellStyleRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_cell_style' } = { 
-    	summary => 'Gets cell`s style description in worksheet.',
+    	summary => 'Retrieve cell style descriptions in the worksheet.',
         params => $params,
         returns => 'StyleResponse',
     };
@@ -137,7 +137,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'Document name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -158,14 +158,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Document`s folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
