@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostChartSecondCategoryAxisRequest.name :   ,
-# PostChartSecondCategoryAxisRequest.sheetName :   ,
-# PostChartSecondCategoryAxisRequest.chartIndex :   ,
-# PostChartSecondCategoryAxisRequest.axis :   ,
-# PostChartSecondCategoryAxisRequest.folder :   ,
-# PostChartSecondCategoryAxisRequest.storageName :    
+# PostChartSecondCategoryAxisRequest.name : The file name.  ,
+# PostChartSecondCategoryAxisRequest.sheetName : The worksheet name.  ,
+# PostChartSecondCategoryAxisRequest.chartIndex : The chart index.  ,
+# PostChartSecondCategoryAxisRequest.axis : Axis   ,
+# PostChartSecondCategoryAxisRequest.folder : The folder where the file is situated.  ,
+# PostChartSecondCategoryAxisRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -144,42 +144,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'chart_index' => {
      	datatype => 'int',
      	base_name => 'chartIndex',
-     	description => '',
+     	description => 'The chart index.',
      	format => '',
      	read_only => '',
      		},
      'axis' => {
      	datatype => 'Axis',
      	base_name => 'axis',
-     	description => '',
+     	description => 'Axis ',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
