@@ -62,8 +62,10 @@ sub new {
 # PostWatermarkRequest.File : e.g. #1032ff  ,
 # PostWatermarkRequest.text :   ,
 # PostWatermarkRequest.color : e.g. #1032ff  ,
-# PostWatermarkRequest.password :   ,
-# PostWatermarkRequest.checkExcelRestriction :    
+# PostWatermarkRequest.outFormat : The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)  ,
+# PostWatermarkRequest.password : The password needed to open an Excel file.  ,
+# PostWatermarkRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
+# PostWatermarkRequest.region : The regional settings for workbook.   
 
 {
     my $params = {
@@ -74,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_watermark' } = { 
-    	summary => 'Add Text Watermark to Excel files.',
+    	summary => 'Add Text Watermark to Excel files and generate output files in various formats.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -108,12 +110,20 @@ sub run_http_request {
         $query_params->{'color'} = $client->to_query_value($self->color);      
     }
 
+    if(defined $self->out_format){
+        $query_params->{'outFormat'} = $client->to_query_value($self->out_format);      
+    }
+
     if(defined $self->password){
         $query_params->{'password'} = $client->to_query_value($self->password);      
     }
 
     if(defined $self->check_excel_restriction){
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
+    }
+
+    if(defined $self->region){
+        $query_params->{'region'} = $client->to_query_value($self->region);      
     } 
     my $_body_data;
  
@@ -156,17 +166,31 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'out_format' => {
+     	datatype => 'string',
+     	base_name => 'outFormat',
+     	description => 'The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)',
+     	format => '',
+     	read_only => '',
+     		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => '',
+     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'region',
+     	description => 'The regional settings for workbook.',
      	format => '',
      	read_only => '',
      		},    
@@ -177,8 +201,10 @@ __PACKAGE__->attribute_map( {
     'file' => 'File',
     'text' => 'text',
     'color' => 'color',
+    'out_format' => 'outFormat',
     'password' => 'password',
-    'check_excel_restriction' => 'checkExcelRestriction' 
+    'check_excel_restriction' => 'checkExcelRestriction',
+    'region' => 'region' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
